{===========================================================================}
{ Mouse Support Turbo Pascal Unit by J.P.Boggis                             }
{===========================================================================}
{ Mouse support unit for Turbo Pascal (Both text and graphics mode are      }
{ supported.)                                                               }
{                                                                           }
{ This unit was developed in 1992 using Borland Turbo Pascal 6.0, but is    }
{ known to work with Turbo Pascal 7.0 also.                                 }
{---------------------------------------------------------------------------}
{ This program is free software; you can redistribute it and/or modify it   }
{ under the terms of the GNU General Public License as published by the     }
{ Free Software Foundation; either version 2 of the License, or (at your    }
{ option) any later version.                                                }
{                                                                           }
{ This program is distributed in the hope that it will be useful, but       }
{ WITHOUT ANY WARRANTY; without even the implied warranty of                }
{ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         }
{ General Public License for more details.                                  }
{                                                                           }
{ You should have received a copy of the GNU General Public License along   }
{ with this program; if not, write to the Free Software Foundation, Inc.,   }
{ 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA                   }
{---------------------------------------------------------------------------}
{ Written - 25/06/1992                                                      }
{===========================================================================}
{ email@jcdigita.com                                       www.jcdigita.com }
{===========================================================================}


unit mouse;

interface

uses dos,crt;

const on=1;
      off=0;

function mouse_installed:boolean;
function get_mousebutt:byte;
procedure mouse_curs(state:byte);
procedure get_mousexy(var mx,my:byte);
procedure get_mousegrafxy(var mx,my:integer);
procedure set_mousexy(mx,my:byte);
procedure set_mousegrafxy(mx,my:integer);
procedure mouse_wait(timeout:word);
procedure mouse_hardware(top,bottom:byte);
function mouse_zone(zx,zy,zw,zh:byte):boolean;
function mouse_grafzone(zx,zy,zw,zh:integer):boolean;

implementation

{Initialise hardware mouse pointer}
procedure mouse_hardware(top,bottom:byte);
var regs:registers;
begin
     with regs do
     begin
          AH:=$0A;
          BX:=$01;
          CX:=top;
          DX:=bottom;
     end;
     intr($33,regs);
end;

{Wait for mouse button to be released with time out value of TIMEOUT 1/10th second}
procedure mouse_wait(timeout:word);
var time_passed:word;
    small_time:byte;
begin
     time_passed:=0;
     while (get_mousebutt<>0) and (time_passed<timeout) do
     begin
          small_time:=0;
          while (small_time<10) and (get_mousebutt<>0) do
          begin
               delay(10);  {Wait for 1/100th second}
               inc(small_time);
          end;
          inc(time_passed);
     end;
end;

{Is mouse installed?}
function mouse_installed:boolean;
var regs:registers;
begin
     with regs do
     begin
          ax:=0;
	  intr($33,regs);
	  mouse_installed:=boolean(ax);
     end;
end;

{Turn mouse cursor on/off}
procedure mouse_curs(state:byte);
var regs:registers;
begin
     if state=on then regs.ax:=1 else regs.ax:=2;
     intr($33,regs);
end;

{Get mouse position on text screen}
procedure get_mousexy(var mx,my:byte);
var regs:registers;
begin
     with regs do
     begin
          ax:=3;
          intr($33,regs);
          mx:=(cx div 8)+1;
          my:=(dx div 8)+1;
     end;
end;

{Get mouse position on graphics screen}
procedure get_mousegrafxy(var mx,my:integer);
var regs:registers;
begin
     with regs do
     begin
          ax:=3;
          intr($33,regs);
          mx:=cx;
          my:=dx;
     end;
end;

{Get mouse button status}
function get_mousebutt:byte;
var regs:registers;
begin
     with regs do
     begin
          ax:=3;
          intr($33,regs);
          get_mousebutt:=bx;
     end;
end;

{Set mouse position on text screen}
procedure set_mousexy(mx,my:byte);
var regs:registers;
begin
     with regs do
     begin
          ax:=4;
          cx:=(mx-1)*8;
          dx:=(my-1)*8;
          intr($33,regs);
     end;
end;

{Set mouse position on graphic screen}
procedure set_mousegrafxy(mx,my:integer);
var regs:registers;
begin
     with regs do
     begin
          ax:=4;
          cx:=mx;
          dx:=my;
          intr($33,regs);
     end;
end;

{See if mouse is in a specified "zone" on the current text screen}
function mouse_zone(zx,zy,zw,zh:byte):boolean;
var mx,my:byte;
begin
     get_mousexy(mx,my);
     if (mx in [zx..zx+pred(zw)]) and (my in [zy..zy+pred(zh)]) then mouse_zone:=true else
        mouse_zone:=false;
end;

{See if mouse is in a specified "zone" on the current graphic screen}
function mouse_grafzone(zx,zy,zw,zh:integer):boolean;
var mx,my:integer;
begin
     get_mousegrafxy(mx,my);
     if ((mx>=zx) and (mx<=zx+pred(zw))) and ((my>=zy) and (my<=zy+pred(zh))) then mouse_grafzone:=true else
        mouse_grafzone:=false;
end;

begin
end.